@@ -1,6 +1,6 @@
 # coding=utf-8
 import sys
-import os
+import threading
 from flask_restful import Resource
 from flask_restful import reqparse
 from flask_restful import marshal_with
@@ -22,6 +22,16 @@ class DutResource(Resource):
     def post(self):
         log.INFO("REST refresh DUT")
         args = PARSER.parse_args()
+        self.start_thread_refresh_dut()
+
+    def start_thread_refresh_dut(self):
+        thread_p = threading.Thread(target=self.refresh_dut)
+        thread_p.setDaemon(True)
+        thread_p.start()
+
+    @staticmethod
+    def refresh_dut():
+        log.INFO("Start refresh DUT")
         dut = Dut()
         dut.refresh()
-
+        log.INFO("End refresh DUT")
