@@ -3,21 +3,22 @@ import os
 from utils import log
 from test_framework.database.database import SqlConnection
 from test_framework.state import SlotState
-from utils.system import get_ip_address
+from utils.system import get_host_name, get_multi_ip_address
 
 
 class DutDatabase(SqlConnection):
 
     def __init__(self):
         super(DutDatabase, self).__init__(db_name="dutdb")
-        self.ip_address = get_ip_address()
+        self.ip_address = get_multi_ip_address()
         self.port = os.environ.get('agent_port', '5000')
         self.agent_table = "agent"
         self.slot_table = "slot"
 
     def update_agent(self, agent):
-        if self.is_exist_agent(self.ip_address, self.port):
-            self.update_exist_agent(agent)
+        agent_id = self.get_agent_id(self.ip_address, self.port)
+        if agent_id is not None:
+            self.update_exist_agent(agent, agent_id)
         else:
             self.create_new_agent(agent)
 
@@ -39,28 +40,41 @@ class DutDatabase(SqlConnection):
         self.cursor.execute(insert_command)
         self.conn.commit()
 
-    def is_exist_agent(self, ip, port):
-        sql_command = "SELECT * from {} WHERE ip='{}' AND port='{}'".format(self.agent_table, ip, port)
-        gets = self.execute_sql_command(sql_command)
-        result = True if gets else False
+    def is_exist_agent(self, ip_addresses, port):
+        result = False
+        for ip in ip_addresses:
+            sql_command = "SELECT * from {} WHERE ip like'%{}%' AND port='{}'".format(self.agent_table, ip, port)
+            gets = self.execute_sql_command(sql_command)
+            if gets:
+                result = True
+                break
         return result
 
+    def get_agent_id(self, ip_addresses, port):
+        agent_id = None
+        for ip in ip_addresses:
+            sql_command = "SELECT * from {} WHERE ip like'%{}%' AND port='{}'".format(self.agent_table, ip, port)
+            gets = self.execute_sql_command(sql_command)
+            if gets:
+                agent_id = gets[0][0]
+                break
+        return agent_id
+
     def is_exist_slot(self, name):
         sql_command = "SELECT * from {} WHERE name='{}'".format(self.slot_table, name)
         gets = self.execute_sql_command(sql_command)
         result = True if gets else False
         return result
 
-    def update_exist_agent(self, agent):
-        str_date = "`os`='{}',platform='{}'".format(agent["os"], agent["platform"])
-        cmd = "UPDATE {} SET {} WHERE ip='{}' AND port='{}'".format(self.agent_table, str_date,
-                                                                     agent["ip"], agent["port"])
+    def update_exist_agent(self, agent, agent_id):
+        str_date = "`os`='{}',platform='{}',ip='{}',name='{}'".format(agent["os"], agent["platform"], agent["ip"], agent["name"])
+        cmd = "UPDATE {} SET {} WHERE `id`='{}'".format(self.agent_table, str_date, agent_id)
         self.cursor.execute(cmd)
         self.conn.commit()
 
     def create_new_agent(self, agent):
         self.insert_to_table(self.agent_table,
-                             name="{}:{}".format(agent["ip"], agent["port"]),
+                             name=agent["name"],
                              ip=agent["ip"],
                              port=agent["port"],
                              os=agent["os"],
@@ -71,11 +85,16 @@ class DutDatabase(SqlConnection):
         result = self.execute_sql_command(cmd)
         return result
 
+    def get_agent_related_slots_by_id(self, agent_id):
+        cmd = "SELECT * FROM {} where `agent`='{}'".format(self.slot_table, agent_id)
+        result = self.execute_sql_command(cmd)
+        return result
+
     def agent_heart_beat(self, state):
         update_time = self.get_datetime()
+        agent_id = self.get_agent_id(self.ip_address, self.port)
         status = "`status`='{}', update_time='{}'".format(state, update_time)
-        update_command = "UPDATE {} SET {} WHERE ip='{}' AND port='{}'".\
-            format(self.agent_table, status, self.ip_address, self.port)
+        update_command = "UPDATE {} SET {} WHERE `id`='{}'".format(self.agent_table, status, agent_id)
         self.cursor.execute(update_command)
         self.conn.commit()
 
@@ -92,6 +111,37 @@ class DutDatabase(SqlConnection):
             self.cursor.execute(cmd)
             self.conn.commit()
 
+    def get_all_agents(self):
+        sql_cmd = "SELECT * from {} ".format(self.agent_table)
+        agents = self.execute_sql_command(sql_cmd)
+        return agents
+
+    def get_all_slots(self):
+        sql_cmd = "SELECT * from {} ".format(self.slot_table)
+        slots = self.execute_sql_command(sql_cmd)
+        return slots
+
+    @staticmethod
+    def map_agent_name_2_id(agent_name, all_agents):
+        agent_id = None
+        for agent in all_agents:
+            if agent[1] == agent_name:
+                agent_id = agent[0]
+                break
+        return agent_id
+
+    def repair_db(self):
+        agents = self.get_all_agents()
+        slots = self.get_all_slots()
+        for slot in slots:
+            agent_name = slot[15]
+            agent_id = self.map_agent_name_2_id(agent_name, agents)
+            if agent_id is not None:
+                cmd = "UPDATE  {} SET `agent`='{}' WHERE `id`='{}'".format(self.slot_table, agent_id, slot[0])
+                self.cursor.execute(cmd)
+                self.conn.commit()
+        pass
+
 
 def update_agent(func):
     def func_wrapper(*args, **kwargs):
@@ -154,29 +204,6 @@ def check_lost_slot(func):
     return func_wrapper
 
 
-# if __name__ == '__main__':
-#     dutdb = DutDatabase()
-#     agent = {
-#         "name": "172.29.128.105:5001",
-#         "ip": "172.29.128.105",
-#         "port": 5001,
-#         "os": "linux",
-#         "platform": "perses"
-#     }
-#
-#     slot = {
-#         "name": "slot3",
-#         "config_name": "oakgate_24_0040",
-#         "slot": "0040",
-#         "vendor": "new_cnexlabs",
-#         "fw_version": "new_PP_10.0.0",
-#         "commit": "new_cfef012dw",
-#         "ise/sed": "new_sed",
-#         "sn": "new_sn0010011002",
-#         "cap": "new_2600000",
-#         "bb": "new_low bb",
-#         "max_ec": "new_120000",
-#         "status": "1",
-#         "agent": "172.29.129.143:5000"
-#
-#     }
+if __name__ == '__main__':
+    dutdb = DutDatabase()
+    dutdb.repair_db()
