@@ -21,3 +21,8 @@ class Dut(object):
     #     for slot in slots:
     #         slot_obj = Slot(slot[0], slot[1], slot[2])
     #         slot_obj.refresh()
+
+
+if __name__ == '__main__':
+    ag = Dut()
+    ag.refresh()
