@@ -8,9 +8,9 @@ from test_framework.state import SlotState
 
 class OakgateSlot(object):
 
-    def __init__(self, slots, agent_name):
+    def __init__(self, slots, agent_id):
         self.db_slots = slots
-        self.agent_name = agent_name
+        self.agent_id = agent_id
         self.orig_log_folders = list()
         self.platform_path = os.environ.get('working_path')
         self.logs_path = os.path.join(self.platform_path, "Logs")
@@ -69,14 +69,14 @@ class OakgateSlot(object):
             "bb": "{}".format(results["drive_life_info_dic"]["count_grown_defects"]),
             "max_ec": results["drive_life_info_dic"]["nand_max_erase_count"],
             "avg_ec": results["drive_life_info_dic"]["nand_avg_erase_count"],
-            "agent": self.agent_name,
+            "agent": self.agent_id,
             "status": SlotState.Idle
         }
         return format_result
 
     @staticmethod
     def convert_t(cap):
-        return float('%.2f' % (cap/1000/1000/1000/1000))
+        return "" if cap == "" else float('%.2f' % (cap/1000/1000/1000/1000))
 
     @update_slot
     def refresh(self, slot_id, config_name):
