@@ -548,6 +548,7 @@ class Tahoe(NVMe):
         fw_private_revision = self.check_data(re.findall('commit (\w+)', id_ctrl_buffer.get('VS'))[0])
         tnvmecap = self.check_data(id_ctrl_buffer.get('TNVMCAP'))
         fw_public_revision = self.check_data(id_ctrl_buffer.get('FR'))
+        vid = self.check_data(id_ctrl_buffer.get('VID'))
         drive_sn = self.check_data(id_ctrl_buffer.get('SN'))
         drive_pn = self.check_data(id_ctrl_buffer.get('MN'))
         security_type = "ISE" if self.check_security(2, 1) else "SED"
@@ -557,8 +558,11 @@ class Tahoe(NVMe):
         count_grown_defects = self.check_data(self.get_vendor_uniquelog(4, 144))
         count_primary_defects = self.check_data(self.get_vendor_uniquelog(4, 152))
         nand_max_erase_count = self.check_data(self.get_vendor_uniquelog(2, 112))
+        nand_min_erase_count = self.check_data(self.get_vendor_uniquelog(2, 96))
+        nand_avg_erase_count = self.check_data(self.get_vendor_uniquelog(2, 104))
         ssd_config_dic['drive_sn'] = drive_sn
         ssd_config_dic['drive_pn'] = drive_pn
+        ssd_config_dic['vid'] = vid
         ssd_config_dic['drive_tnvmcap'] = tnvmecap
         ssd_config_dic['security_status'] = security_status
         ssd_config_dic['security_type'] = security_type
@@ -567,6 +571,8 @@ class Tahoe(NVMe):
         drive_life_info_dic['count_grown_defects'] = count_grown_defects
         drive_life_info_dic['count_primary_defects'] = count_primary_defects
         drive_life_info_dic['nand_max_erase_count'] = nand_max_erase_count
+        drive_life_info_dic['nand_min_erase_count'] = nand_min_erase_count
+        drive_life_info_dic['nand_avg_erase_count'] = nand_avg_erase_count
         test_fw_config_dic['fw_public_revision'] = fw_public_revision
         test_fw_config_dic['fw_repo'] = fw_repo
         test_fw_config_dic['fw_private_revision'] = fw_private_revision
@@ -574,4 +580,4 @@ class Tahoe(NVMe):
         dev_info['ssd_config_dic'] = ssd_config_dic
         dev_info['drive_life_info_dic'] = drive_life_info_dic
         dev_info['test_fw_config_dic'] = test_fw_config_dic
-        return dev_info
\ No newline at end of file
+        return dev_info
