@@ -54,6 +54,20 @@ def get_ip_address():
     return ip_address
 
 
+def get_multi_ip_address():
+    address = list()
+    add_info = socket.getaddrinfo(socket.gethostname(), None)
+    for item in add_info:
+        if ':' not in item[4][0]:
+            address.append(item[4][0])
+    return address
+
+
+def get_host_name():
+    name = socket.gethostname()
+    return name
+
+
 def get_root_path():
     root_path = os.path.join(os.path.dirname(__file__), "..")
     return root_path
@@ -117,5 +131,22 @@ def get_platform():
     return slot_type
 
 
+def get_vendor_name(vendor_id):
+    print("vendor: input {}".format(vendor_id))
+    vendor_id = hex(int(vendor_id)).replace("0x", "")
+    vendor_name = ""
+    pci_ids_file = os.path.join(os.path.dirname(__file__), "..",  "configuration", "pci.ids")
+    with open(pci_ids_file, encoding='UTF-8') as pci_file:
+        while True:
+            line = pci_file.readline()
+            if line:
+                if not line.startswith("\t"):
+                    if vendor_id.lower() in line.lower():
+                        vendor_name = line.split(vendor_id)[1].strip()
+                        break
+            else:
+                break
+    return vendor_name
+
 ROOT_PATH = get_root_path()
 
